@@ -39,6 +39,7 @@ class TestTracWikiImporter(TestCase):
         app.url = 'foo'
         project = Mock(name='Project', shortname='myproject')
         project.install_app.return_value = app
+        project.url.return_value = '/nbhd/foobar/subproj/'
         user = Mock(name='User', _id='id')
         res = importer.import_tool(project, user,
                 mount_point='pages',
@@ -103,38 +104,62 @@ class TestTracWikiImportController(TestController, TestCase):
         self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
 
     @with_wiki
+    @patch('forgeimporters.trac.requests.head')
     @patch('forgeimporters.base.import_tool')
-    def test_create(self, import_tool):
-        params = dict(trac_url='http://example.com/trac/url',
-                mount_label='mylabel',
-                mount_point='mymount',
-                )
+    def test_create(self, import_tool, head):
+        head.return_value.status_code = 200
+        params = dict(
+            trac_url='http://example.com/trac/url',
+            mount_label='mylabel',
+            mount_point='mymount',
+        )
         r = self.app.post('/p/test/admin/wiki/_importer/create', params,
-                status=302)
+                          status=302)
         self.assertEqual(r.location, 'http://localhost/p/test/admin/')
-        self.assertEqual(u'mymount', import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual(u'mylabel', import_tool.post.call_args[1]['mount_label'])
-        self.assertEqual(u'http://example.com/trac/url', import_tool.post.call_args[1]['trac_url'])
+        self.assertEqual(u'mymount',
+                         import_tool.post.call_args[1]['mount_point'])
+        self.assertEqual(u'mylabel',
+                         import_tool.post.call_args[1]['mount_label'])
+        self.assertEqual(u'http://example.com/trac/url/',
+                         import_tool.post.call_args[1]['trac_url'])
 
     @with_wiki
+    @patch('forgeimporters.trac.requests.head')
     @patch('forgeimporters.base.import_tool')
-    def test_create_limit(self, import_tool):
+    def test_create_limit(self, import_tool, head):
+        head.return_value.status_code = 200
         project = M.Project.query.get(shortname='test')
         project.set_tool_data('TracWikiImporter', pending=1)
         ThreadLocalORMSession.flush_all()
-        params = dict(trac_url='http://example.com/trac/url',
-                mount_label='mylabel',
-                mount_point='mymount',
-                )
+        params = dict(
+            trac_url='http://example.com/trac/url',
+            mount_label='mylabel',
+            mount_point='mymount',
+        )
         r = self.app.post('/p/test/admin/wiki/_importer/create', params,
-                status=302).follow()
+                          status=302).follow()
         self.assertIn('Please wait and try again', r)
         self.assertEqual(import_tool.post.call_count, 0)
 
+    @with_wiki
+    @patch('forgeimporters.trac.requests.head')
+    @patch('forgeimporters.base.import_tool')
+    def test_created_not_found(self, import_tool, head):
+        head.return_value.status_code = 404
+        params = dict(
+            trac_url='http://example.com/trac/url',
+            mount_label='mylabel',
+            mount_point='mymount',
+        )
+        r = self.app.post('/p/test/admin/wiki/_importer/create', params)
+        self.assertEqual(import_tool.post.call_count, 0)
+
 
 class TestWikiExporter(TestCase):
 
-    def test_url_canonicalization(self):
+    @patch('forgeimporters.trac.requests')
+    def test_url_canonicalization(self, requests):
+        requests.head.return_value.status_code = 200
         test_urls = [
             'https://sourceforge.net/apps/trac/shareaza',
             'https://sourceforge.net/apps/trac/shareaza/',
@@ -150,6 +175,10 @@ class TestWikiExporter(TestCase):
 
     def test_page_list__special_chars(self):
         class WikiExporterFunnyPages(WikiExporter):
+            def __init__(self, base_url, options):
+                self.base_url = base_url
+                self.options = options
+
             def fetch(self, url):
                 return '''
                     <div class="wikipage searchable">
